// e02_histogram.cpp: Create histogram of one image
//
#include "opencv\cv.hpp"
#include <iostream>

using namespace cv;
using namespace std;

int main(int, char**)
{
	// Objects
	Mat img_original;

	// Load image from disk
	img_original = imread("mandril.jpg", 0);
	if (!img_original.data){
		cout << "error loading image" << endl;
		return 1;
	}

	// Create window canvas to show image
	namedWindow("original", CV_WINDOW_AUTOSIZE);
	namedWindow("histogram", CV_WINDOW_AUTOSIZE);
	
	// Initialize parameters
	int histSize = 256;    // bin size
	float range[] = { 0, 255 };
	const float *ranges[] = { range };

	// Calculate histogram
	Mat hist;
	calcHist(&img_original, 1, 0, Mat(), hist, 1, &histSize, ranges, true, false);

	// Show the calculated histogram in command window
	double total;
	total = img_original.rows * img_original.cols;
	for (int h = 0; h < histSize; h++)
	{
		float binVal = hist.at<float>(h);
		cout << " " << binVal;
	}

	// Plot the histogram
	int hist_w = 512; int hist_h = 400;
	int bin_w = cvRound((double)hist_w / histSize);

	Mat histImage(hist_h, hist_w, CV_8UC1, Scalar(0, 0, 0));

	// In order to fit in window sized 400x500 must be normalized:
	// max value of same color pixel = 2740 --> 500
	normalize(hist, hist, 0, histImage.rows, NORM_MINMAX, -1, Mat());

	for (int i = 1; i < histSize; i++)
	{
		line(histImage, Point(bin_w*(i - 1), hist_h - cvRound(hist.at<float>(i - 1))),
			Point(bin_w*(i), hist_h - cvRound(hist.at<float>(i))),
			Scalar(255, 0, 0), 2, 8, 0);
	}

	imshow("original", img_original);
	imshow("histogram", histImage);

	waitKey(0);

	destroyAllWindows();
	return 0;
}